==> common-2.0.0-sources.jar: cn/gtmap/gtc/resource/domain/resource/metadata/ResourceApply.java <==
package cn.gtmap.gtc.resource.domain.resource.metadata;

import cn.gtmap.gtc.resource.domain.BaseEntity;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import java.util.Date;


/**
 * resource apply
 *
 * @author monarchCheng
 * @create 2017-11-10 13:45
 **/
@Entity
@Table(name = "gt_resource_apply")
public class ResourceApply extends BaseEntity {
    /**
     * 任务id
     */
    private String taskId;

    /**
     * 流程id
     */
    private String processId;
    /**
     * 资源描述
     */
    private String description;
    /**
     * 资源标题
     */
    private String title;
    /**
     * 申请者别名
     */
    private String applicant;

    /**
     * 申请者登录名
     */
    private String applicantName;

    /**
     * 申请数据
     */
    private String applicationData;

    /**
     * 部门
     */
    private String department;
    /**
     * 审核者
     */
    private String auditor;
    /**
     * 申请理由
     */
    private String applyReason;
    /**
     * 资源id
     */
    private String resourceId;

    /**
     * 资源能力id，多个以逗号
     */
    private String capables;

    /**
     * 审批意见
     */
    private String option;
    /**
     * 审批状态
     */
    private String agree;
    /**
     * 资源类型
     */
    private String type;
    /**
     * 操作时间
     */
    private Date operateTime;
    /**
     * 缩略图
     */
    private String icon;

    private String cloumname;

    private String cloumaliasname;

    private String cloumnameenable;

    private String filemessage;

    public String getFilemessage() {
        return filemessage;
    }

    public void setFilemessage(String filemessage) {
        this.filemessage = filemessage;
    }

    public String getCloumnameenable() {
        return cloumnameenable;
    }

    public void setCloumnameenable(String cloumnameenable) {
        this.cloumnameenable = cloumnameenable;
    }

    public String getCloumname() {
        return cloumname;
    }

    public void setCloumname(String cloumname) {
        this.cloumname = cloumname;
    }

    public String getCloumaliasname() {
        return cloumaliasname;
    }

    public void setCloumaliasname(String cloumaliasname) {
        this.cloumaliasname = cloumaliasname;
    }

    public String getDepartment() {
        return department;
    }

    public void setDepartment(String department) {
        this.department = department;
    }

    public String getDescription() {
        return description;
    }

    public ResourceApply setDescription(String description) {
        this.description = description;
        return this;
    }

    public String getApplicant() {
        return applicant;
    }

    public ResourceApply setApplicant(String applicant) {
        this.applicant = applicant;
        return this;
    }


    public String getAuditor() {
        return auditor;
    }

    public ResourceApply setAuditor(String auditor) {
        this.auditor = auditor;
        return this;
    }

    public String getResourceId() {
        return resourceId;
    }

    public ResourceApply setResourceId(String resourceId) {
        this.resourceId = resourceId;
        return this;
    }


    public String getCapables() {
        return capables;
    }

    public void setCapables(String capables) {
        this.capables = capables;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    @Column(name = "apply_option")
    public String getOption() {
        return option;
    }

    public void setOption(String option) {
        this.option = option;
    }

    public String getAgree() {
        return agree;
    }

    public void setAgree(String agree) {
        this.agree = agree;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Date getOperateTime() {
        return operateTime;
    }

    public void setOperateTime(Date operateTime) {
        this.operateTime = operateTime;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getProcessId() {
        return processId;
    }

    public void setProcessId(String processId) {
        this.processId = processId;
    }


    public String getApplicantName() {
        return applicantName;
    }

    public void setApplicantName(String applicantName) {
        this.applicantName = applicantName;
    }

    public String getApplicationData() {
        return applicationData;
    }

    public void setApplicationData(String applicationData) {
        this.applicationData = applicationData;
    }

}

==> common-2.0.2-sources.jar: cn/gtmap/gtc/resource/domain/resource/metadata/ResourceApply.java <==
package cn.gtmap.gtc.resource.domain.resource.metadata;

import cn.gtmap.gtc.resource.domain.BaseEntity;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import org.hibernate.annotations.NotFound;
import org.hibernate.annotations.NotFoundAction;

import javax.persistence.*;
import java.util.Date;


/**
 * resource apply
 *
 * @author monarchCheng
 * @create 2017-11-10 13:45
 **/
@Entity
@Table(name = "gt_resource_apply")
public class ResourceApply extends BaseEntity {
    /**
     * 任务id
     */
    private String taskId;

    /**
     * 流程id
     */
    private String processId;
    /**
     * 资源描述
     */
    private String description;
    /**
     * 资源标题
     */
    private String title;
    /**
     * 申请者别名
     */
    private String applicant;

    /**
     * 申请者登录名
     */
    private String applicantName;

    /**
     * 申请数据
     */
    private String applicationData;

    /**
     * 部门
     */
    private String department;
    /**
     * 审核者
     */
    private String auditor;
    /**
     * 申请理由
     */
    private String applyReason;
    /**
     * 资源id
     */
    private String resourceId;

    /**
     * 资源能力id，多个以逗号
     */
    private String capables;

    /**
     * 审批意见
     */
    private String option;
    /**
     * 审批状态
     */
    private String agree;
    /**
     * 资源类型
     */
    private String type;
    /**
     * 操作时间
     */
    private Date operateTime;
    /**
     * 缩略图
     */
    private String icon;

    private String cloumname;

    private String cloumaliasname;

    private String cloumnameenable;

    private String filemessage;

    /**
     * 声明外键-资源表
     */
    private Resource foreignResource;

    /**
     * 声明多对一的外键
     * @return
     */
    @JsonIgnore
    @ManyToOne(fetch = FetchType.LAZY)
    @JoinColumn(name = "foreign_resource_id")
    public Resource getForeignResource() {
        return foreignResource;
    }
    public ResourceApply setForeignResource(Resource foreignResource) {
        this.foreignResource = foreignResource;
        return this;
    }

    public String getFilemessage() {
        return filemessage;
    }

    public void setFilemessage(String filemessage) {
        this.filemessage = filemessage;
    }

    public String getCloumnameenable() {
        return cloumnameenable;
    }

    public void setCloumnameenable(String cloumnameenable) {
        this.cloumnameenable = cloumnameenable;
    }

    public String getCloumname() {
        return cloumname;
    }

    public void setCloumname(String cloumname) {
        this.cloumname = cloumname;
    }

    public String getCloumaliasname() {
        return cloumaliasname;
    }

    public void setCloumaliasname(String cloumaliasname) {
        this.cloumaliasname = cloumaliasname;
    }

    public String getDepartment() {
        return department;
    }

    public void setDepartment(String department) {
        this.department = department;
    }

    public String getDescription() {
        return description;
    }

    public ResourceApply setDescription(String description) {
        this.description = description;
        return this;
    }

    public String getApplicant() {
        return applicant;
    }

    public ResourceApply setApplicant(String applicant) {
        this.applicant = applicant;
        return this;
    }


    public String getAuditor() {
        return auditor;
    }

    public ResourceApply setAuditor(String auditor) {
        this.auditor = auditor;
        return this;
    }

    public String getResourceId() {
        return resourceId;
    }

    public ResourceApply setResourceId(String resourceId) {
        this.resourceId = resourceId;
        return this;
    }


    public String getCapables() {
        return capables;
    }

    public void setCapables(String capables) {
        this.capables = capables;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getApplyReason() {
        return applyReason;
    }

    public void setApplyReason(String applyReason) {
        this.applyReason = applyReason;
    }

    @Column(name = "apply_option")
    public String getOption() {
        return option;
    }

    public void setOption(String option) {
        this.option = option;
    }

    public String getAgree() {
        return agree;
    }

    public void setAgree(String agree) {
        this.agree = agree;
    }

    public String getTaskId() {
        return taskId;
    }

    public void setTaskId(String taskId) {
        this.taskId = taskId;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public Date getOperateTime() {
        return operateTime;
    }

    public void setOperateTime(Date operateTime) {
        this.operateTime = operateTime;
    }

    public String getIcon() {
        return icon;
    }

    public void setIcon(String icon) {
        this.icon = icon;
    }

    public String getProcessId() {
        return processId;
    }

    public void setProcessId(String processId) {
        this.processId = processId;
    }


    public String getApplicantName() {
        return applicantName;
    }

    public void setApplicantName(String applicantName) {
        this.applicantName = applicantName;
    }

    public String getApplicationData() {
        return applicationData;
    }

    public void setApplicationData(String applicationData) {
        this.applicationData = applicationData;
    }

}
